@@ -39,8 +39,14 @@ def raise_exception(e):
 # dictionary of global helper functions to be added to the Jinja2 environment;
 # as each function is defined, they are added to this and then it iterated
 # through, to extend the environment later
+#
+# the list is initialised to include some functions which are imported
 
-global_helpers = {}
+global_helpers = {
+    "deepcopy": deepcopy,
+    "deepmerge": deepmerge,
+    "deepremoveitems": deepremoveitems
+}
 
 
 
